@@ -3,6 +3,7 @@
 
 """
 ===============================================================================
+
     Copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
@@ -18,6 +19,7 @@
     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     See the License for the specific language governing permissions and
     limitations under the License.
+
 ===============================================================================
 """
 
@@ -25,8 +27,8 @@ from typing import Any, Callable
 
 from django.contrib.admin import AdminSite, ModelAdmin
 # from django.db.models import Model
-from django.core.urlresolvers import reverse
 from django.utils.html import escape
+from django.urls import reverse
 
 
 # =============================================================================
