@@ -3,6 +3,7 @@
 
 """
 ===============================================================================
+
     Copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
@@ -18,6 +19,7 @@
     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     See the License for the specific language governing permissions and
     limitations under the License.
+
 ===============================================================================
 """
 
@@ -217,7 +219,7 @@ def get_literal_query(statement: Union[Query, Executable],
             elif (isinstance(value, datetime.datetime) or
                   isinstance(value, datetime.date) or
                   isinstance(value, datetime.time) or
-                  isinstance(value, pendulum.Pendulum) or
+                  isinstance(value, pendulum.DateTime) or
                   isinstance(value, pendulum.Date) or
                   isinstance(value, pendulum.Time)):
                 # All have an isoformat() method.
