@@ -3,6 +3,7 @@
 
 """
 ===============================================================================
+
     Copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
@@ -18,10 +19,11 @@
     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     See the License for the specific language governing permissions and
     limitations under the License.
+
 ===============================================================================
 """
 
-VERSION = '1.0.16'
+VERSION = '1.0.18'
 # Use semantic versioning: http://semver.org/
 
 RECENT_VERSION_HISTORY = r"""
@@ -82,9 +84,16 @@ First started in 2009.
 - 1.0.15, 2018-05-04
   There was a bad character in a comment in winservice.py; fixed.
   
-- 1.0.16, 2018-05-22 IN PROGRESS
+- 1.0.16, 2018-05-22
   - New file sqlalchemy/engine_func.py
   - JSON serialization of pendulum.Date
   - @register_enum_for_json
+  
+- 1.0.17, 2018-05-27 IN PROGRESS
+  - lazy dictionaries
+  
+- 1.0.18, 2018-06-29
+  - update for Django 2.0+
+  - update for Pendulum 2.0+
 
 """
